==> ews-javascript-api-0.1.3.tgz: package/js/PropertyDefinitions/ServiceObjectPropertyDefinition.js <==
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var ExchangeVersion_1 = require("../Enumerations/ExchangeVersion");
var XmlAttributeNames_1 = require("../Core/XmlAttributeNames");
var XmlElementNames_1 = require("../Core/XmlElementNames");
var EwsLogging_1 = require("../Core/EwsLogging");
var ExtensionMethods_1 = require("../ExtensionMethods");
var PropertyDefinitionBase_1 = require("./PropertyDefinitionBase");
//should be done except JSON
var ServiceObjectPropertyDefinition = (function (_super) {
    __extends(ServiceObjectPropertyDefinition, _super);
    function ServiceObjectPropertyDefinition(uri) {
        _super.call(this);
        if (uri !== undefined) {
            EwsLogging_1.EwsLogging.Assert(!ExtensionMethods_1.StringHelper.IsNullOrEmpty(uri), "ServiceObjectPropertyDefinition.ctor", "uri is null or empty");
            this.uri = uri;
        }
    }
    Object.defineProperty(ServiceObjectPropertyDefinition.prototype, "Version", {
        get: function () { return ExchangeVersion_1.ExchangeVersion.Exchange2007_SP1; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ServiceObjectPropertyDefinition.prototype, "Uri", {
        get: function () { return this.uri; },
        enumerable: true,
        configurable: true
    });
    //AddJsonProperties(jsonPropertyDefinition: JsonObject, service: ExchangeService): any { jsonPropertyDefinition.Add(XmlAttributeNames.FieldURI, this.Uri); }
    //GetJsonType(): string{ throw new Error("ServiceObjectPropertyDefinition.ts - GetJsonType : Not implemented.");}
    ServiceObjectPropertyDefinition.prototype.GetXmlElementName = function () { return XmlElementNames_1.XmlElementNames.FieldURI; };
    ServiceObjectPropertyDefinition.prototype.WriteAttributesToXml = function (writer) {
        writer.WriteAttributeValue("", XmlAttributeNames_1.XmlAttributeNames.FieldURI, this.Uri);
    };
    return ServiceObjectPropertyDefinition;
})(PropertyDefinitionBase_1.PropertyDefinitionBase);
exports.ServiceObjectPropertyDefinition = ServiceObjectPropertyDefinition;

==> ews-javascript-api-0.1.11.tgz: package/js/PropertyDefinitions/ServiceObjectPropertyDefinition.js <==
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var ExchangeVersion_1 = require("../Enumerations/ExchangeVersion");
var XmlAttributeNames_1 = require("../Core/XmlAttributeNames");
var XmlElementNames_1 = require("../Core/XmlElementNames");
var EwsLogging_1 = require("../Core/EwsLogging");
var ExtensionMethods_1 = require("../ExtensionMethods");
var PropertyDefinitionBase_1 = require("./PropertyDefinitionBase");
//should be done except JSON
var ServiceObjectPropertyDefinition = (function (_super) {
    __extends(ServiceObjectPropertyDefinition, _super);
    function ServiceObjectPropertyDefinition(uri) {
        _super.call(this);
        if (uri !== undefined) {
            EwsLogging_1.EwsLogging.Assert(!ExtensionMethods_1.StringHelper.IsNullOrEmpty(uri), "ServiceObjectPropertyDefinition.ctor", "uri is null or empty");
            this.uri = uri;
        }
    }
    Object.defineProperty(ServiceObjectPropertyDefinition.prototype, "Version", {
        get: function () { return ExchangeVersion_1.ExchangeVersion.Exchange2007_SP1; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ServiceObjectPropertyDefinition.prototype, "Uri", {
        get: function () { return this.uri; },
        enumerable: true,
        configurable: true
    });
    //AddJsonProperties(jsonPropertyDefinition: JsonObject, service: ExchangeService): any { jsonPropertyDefinition.Add(XmlAttributeNames.FieldURI, this.Uri); }
    //GetJsonType(): string{ throw new Error("ServiceObjectPropertyDefinition.ts - GetJsonType : Not implemented.");}
    ServiceObjectPropertyDefinition.prototype.GetXmlElementName = function () { return XmlElementNames_1.XmlElementNames.FieldURI; };
    ServiceObjectPropertyDefinition.prototype.WriteAttributesToXml = function (writer) {
        writer.WriteAttributeValue(XmlAttributeNames_1.XmlAttributeNames.FieldURI, this.Uri);
    };
    return ServiceObjectPropertyDefinition;
})(PropertyDefinitionBase_1.PropertyDefinitionBase);
exports.ServiceObjectPropertyDefinition = ServiceObjectPropertyDefinition;
